@@ -54,8 +54,8 @@ class RegisterOrUpdateNodes(base.TripleOAction):
             caps.setdefault('boot_option', self.instance_boot_option)
             node['capabilities'] = nodes.dict_to_capabilities(caps)
 
-        baremetal_client = self._get_baremetal_client()
-        image_client = self._get_image_client()
+        baremetal_client = self.get_baremetal_client()
+        image_client = self.get_image_client()
 
         try:
             return nodes.register_all_nodes(
@@ -64,14 +64,10 @@ class RegisterOrUpdateNodes(base.TripleOAction):
                 remove=self.remove,
                 glance_client=image_client,
                 kernel_name=self.kernel_name,
-                ramdisk_name=self.ramdisk_name,
-                provide=False)
+                ramdisk_name=self.ramdisk_name)
         except Exception as err:
             LOG.exception("Error registering nodes with ironic.")
-            return mistral_workflow_utils.Result(
-                "",
-                err.message
-            )
+            return mistral_workflow_utils.Result(error=err)
 
 
 class ConfigureBootAction(base.TripleOAction):
@@ -93,8 +89,8 @@ class ConfigureBootAction(base.TripleOAction):
         self.instance_boot_option = instance_boot_option
 
     def run(self):
-        baremetal_client = self._get_baremetal_client()
-        image_client = self._get_image_client()
+        baremetal_client = self.get_baremetal_client()
+        image_client = self.get_image_client()
 
         try:
             image_ids = {'kernel': None, 'ramdisk': None}
@@ -134,7 +130,7 @@ class ConfigureBootAction(base.TripleOAction):
             LOG.debug("Configuring boot option for Node %s", self.node_uuid)
         except Exception as err:
             LOG.exception("Error configuring node boot options with Ironic.")
-            return mistral_workflow_utils.Result("", err)
+            return mistral_workflow_utils.Result(error=err)
 
 
 class ConfigureRootDeviceAction(base.TripleOAction):
@@ -162,7 +158,7 @@ class ConfigureRootDeviceAction(base.TripleOAction):
         if not self.root_device:
             return
 
-        baremetal_client = self._get_baremetal_client()
+        baremetal_client = self.get_baremetal_client()
         node = baremetal_client.node.get(self.node_uuid)
         self._apply_root_device_strategy(
             node, self.root_device, self.minimum_size, self.overwrite)
@@ -182,7 +178,7 @@ class ConfigureRootDeviceAction(base.TripleOAction):
                         node.uuid)
             return
 
-        inspector_client = self._get_baremetal_introspection_client()
+        inspector_client = self.get_baremetal_introspection_client()
         try:
             data = inspector_client.get_data(node.uuid)
         except ironic_inspector_client.ClientError:
@@ -248,7 +244,7 @@ class ConfigureRootDeviceAction(base.TripleOAction):
         # This -1 is what we always do to account for partitioning
         new_size -= 1
 
-        bm_client = self._get_baremetal_client()
+        bm_client = self.get_baremetal_client()
         bm_client.node.update(
             node.uuid,
             [{'op': 'add', 'path': '/properties/root_device', 'value': hint},
@@ -277,7 +273,7 @@ class UpdateNodeCapability(base.TripleOAction):
         self.value = value
 
     def run(self):
-        baremetal_client = self._get_baremetal_client()
+        baremetal_client = self.get_baremetal_client()
 
         try:
             return nodes.update_node_capability(
@@ -289,6 +285,5 @@ class UpdateNodeCapability(base.TripleOAction):
         except Exception as err:
             LOG.exception("Error updating node capability in ironic.")
             return mistral_workflow_utils.Result(
-                "",
-                "%s: %s" % (type(err).__name__, str(err))
+                error="%s: %s" % (type(err).__name__, str(err))
             )
