@@ -20,7 +20,6 @@ from heatclient.common import deployment_utils
 from heatclient import exc as heat_exc
 from mistral.workflow import utils as mistral_workflow_utils
 from mistralclient.api import base as mistralclient_exc
-from swiftclient import exceptions as swiftexceptions
 
 from tripleo_common.actions import base
 from tripleo_common.actions import templates
@@ -68,7 +67,7 @@ class OrchestrationDeployAction(base.TripleOAction):
     def _wait_for_data(self, container_name, object_name):
         body = None
         count_check = 0
-        swift_client = self._get_object_client()
+        swift_client = self.get_object_client()
         while not body:
             headers, body = swift_client.get_object(
                 container_name,
@@ -82,8 +81,8 @@ class OrchestrationDeployAction(base.TripleOAction):
         return body
 
     def run(self):
-        heat = self._get_orchestration_client()
-        swift_client = self._get_object_client()
+        heat = self.get_orchestration_client()
+        swift_client = self.get_object_client()
 
         swift_url = deployment_utils.create_temp_url(swift_client,
                                                      self.name,
@@ -122,24 +121,19 @@ class OrchestrationDeployAction(base.TripleOAction):
             if body_json['deploy_status_code'] != 0:
                 error = "Heat deployment failed for '%s'" % self.name
 
-        return mistral_workflow_utils.Result(
-            body_json,
-            error
-        )
+        return mistral_workflow_utils.Result(data=body_json, error=error)
 
 
 class DeployStackAction(templates.ProcessTemplatesAction):
     """Deploys a heat stack."""
 
-    def __init__(self, timeout, container=constants.DEFAULT_CONTAINER_NAME,
-                 skip_deploy_identifier=False):
+    def __init__(self, timeout, container=constants.DEFAULT_CONTAINER_NAME):
         super(DeployStackAction, self).__init__(container)
         self.timeout_mins = timeout
-        self.skip_deploy_identifier = skip_deploy_identifier
 
     def run(self):
         # check to see if the stack exists
-        heat = self._get_orchestration_client()
+        heat = self.get_orchestration_client()
         try:
             stack = heat.stacks.get(self.container)
         except heat_exc.HTTPNotFound:
@@ -148,12 +142,11 @@ class DeployStackAction(templates.ProcessTemplatesAction):
         stack_is_new = stack is None
 
         # update StackAction, DeployIdentifier and UpdateIdentifier
-        wc = self._get_workflow_client()
+        wc = self.get_workflow_client()
         wf_env = wc.environments.get(self.container)
 
         parameters = dict()
-        if not self.skip_deploy_identifier:
-            parameters['DeployIdentifier'] = int(time.time())
+        parameters['DeployIdentifier'] = int(time.time())
         parameters['UpdateIdentifier'] = ''
         parameters['StackAction'] = 'CREATE' if stack_is_new else 'UPDATE'
 
@@ -179,16 +172,6 @@ class DeployStackAction(templates.ProcessTemplatesAction):
         stack_args['timeout_mins'] = self.timeout_mins
 
         if stack_is_new:
-            swift_client = self._get_object_client()
-            try:
-                swift_client.copy_object(
-                    "%s-swift-rings" % self.container, "swift-rings.tar.gz",
-                    "%s-swift-rings/%s-%d" % (
-                        self.container, "swift-rings.tar.gz", time.time()))
-                swift_client.delete_object(
-                    "%s-swift-rings" % self.container, "swift-rings.tar.gz")
-            except swiftexceptions.ClientException:
-                pass
             LOG.info("Perfoming Heat stack create")
             return heat.stacks.create(**stack_args)
 
@@ -212,8 +195,8 @@ class OvercloudRcAction(base.TripleOAction):
         self.no_proxy = no_proxy
 
     def run(self):
-        orchestration_client = self._get_orchestration_client()
-        workflow_client = self._get_workflow_client()
+        orchestration_client = self.get_orchestration_client()
+        workflow_client = self.get_workflow_client()
 
         try:
             stack = orchestration_client.stacks.get(self.container)
