@@ -12,13 +12,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import os
+import shutil
+import tempfile
+
 from mistral.workflow import utils as mistral_workflow_utils
 from mistralclient.api import base as mistralclient_api
 from oslo_concurrency.processutils import ProcessExecutionError
 
 from tripleo_common.actions import base
 from tripleo_common import constants
-from tripleo_common.utils import passwords as password_utils
 from tripleo_common.utils import validations as utils
 
 
@@ -27,18 +30,30 @@ class GetPubkeyAction(base.TripleOAction):
         super(GetPubkeyAction, self).__init__()
 
     def run(self):
-        mc = self._get_workflow_client()
+        mc = self.get_workflow_client()
         try:
             env = mc.environments.get('ssh_keys')
             public_key = env.variables['public_key']
         except Exception:
-            ssh_key = password_utils.create_ssh_keypair()
-            public_key = ssh_key['public_key']
+            tmp_dir = tempfile.mkdtemp()
+            private_key_path = os.path.join(tmp_dir, 'id_rsa')
+            public_key_path = private_key_path + '.pub'
+            utils.create_ssh_keypair(private_key_path)
+
+            with open(private_key_path, 'r') as f:
+                private_key = f.read().strip()
+            with open(public_key_path, 'r') as f:
+                public_key = f.read().strip()
+
+            shutil.rmtree(tmp_dir)
 
             workflow_env = {
                 'name': 'ssh_keys',
                 'description': 'SSH keys for TripleO validations',
-                'variables': ssh_key
+                'variables': {
+                    'public_key': public_key,
+                    'private_key': private_key,
+                }
             }
             mc.environments.create(**workflow_env)
 
@@ -53,7 +68,7 @@ class Enabled(base.TripleOAction):
 
     def _validations_enabled(self):
         """Detect whether the validations are enabled on the undercloud."""
-        mistral = self._get_workflow_client()
+        mistral = self.get_workflow_client()
         try:
             # NOTE: the `ssh_keys` environment is created by
             # instack-undercloud only when the validations are enabled on the
@@ -68,11 +83,11 @@ class Enabled(base.TripleOAction):
         return_value = {'stderr': ''}
         if self._validations_enabled():
             return_value['stdout'] = 'Validations are enabled'
-            mistral_result = (return_value, None)
+            mistral_result = {"data": return_value}
         else:
             return_value['stdout'] = 'Validations are disabled'
-            mistral_result = (None, return_value)
-        return mistral_workflow_utils.Result(*mistral_result)
+            mistral_result = {"error": return_value}
+        return mistral_workflow_utils.Result(**mistral_result)
 
 
 class ListValidationsAction(base.TripleOAction):
@@ -106,7 +121,7 @@ class RunValidationAction(base.TripleOAction):
         self.plan = plan
 
     def run(self):
-        mc = self._get_workflow_client()
+        mc = self.get_workflow_client()
         identity_file = None
         try:
             env = mc.environments.get('ssh_keys')
@@ -117,15 +132,15 @@ class RunValidationAction(base.TripleOAction):
                                                   identity_file,
                                                   self.plan)
             return_value = {'stdout': stdout, 'stderr': stderr}
-            mistral_result = (return_value, None)
+            mistral_result = {"data": return_value}
         except mistralclient_api.APIException as e:
             return_value = {'stdout': '', 'stderr': e.error_message}
-            mistral_result = (None, return_value)
+            mistral_result = {"error": return_value}
         except ProcessExecutionError as e:
             return_value = {'stdout': e.stdout, 'stderr': e.stderr}
             # Indicates to Mistral there was a failure
-            mistral_result = (None, return_value)
+            mistral_result = {"error": return_value}
         finally:
             if identity_file:
                 utils.cleanup_identity_file(identity_file)
-        return mistral_workflow_utils.Result(*mistral_result)
+        return mistral_workflow_utils.Result(**mistral_result)
