@@ -75,13 +75,15 @@ PASSWORD_PARAMETER_NAMES = (
     'IronicPassword',
     'KeystoneCredential0',
     'KeystoneCredential1',
+    'KeystoneFernetKey0',
+    'KeystoneFernetKey1',
     'ManilaPassword',
     'MistralPassword',
     'MysqlClustercheckPassword',
     'NeutronMetadataProxySharedSecret',
     'NeutronPassword',
     'NovaPassword',
-    'MigrationSshKey',
+    'PankoPassword',
     'RabbitPassword',
     'RedisPassword',
     'SaharaPassword',
