@@ -57,7 +57,7 @@ class OrchestrationDeployActionTest(base.TestCase):
         self.assertEqual('built_params', action._build_sc_params('swift_url'))
         build_derived_config_params_mock.assert_called_once()
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     def test_wait_for_data(self, get_obj_client_mock):
         swift = mock.MagicMock()
         swift.get_object.return_value = ({}, 'body')
@@ -69,7 +69,7 @@ class OrchestrationDeployActionTest(base.TestCase):
         get_obj_client_mock.assert_called_once()
         swift.get_object.assert_called_once_with('container', 'object')
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch('time.sleep')
     def test_wait_for_data_timeout(self, sleep, get_obj_client_mock):
         swift = mock.MagicMock()
@@ -85,9 +85,9 @@ class OrchestrationDeployActionTest(base.TestCase):
         # Trying every 3 seconds, so 4 times for a timeout of 10 seconds
         self.assertEqual(swift.get_object.call_count, 4)
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('heatclient.common.deployment_utils.create_temp_url')
     @mock.patch('tripleo_common.actions.deployment.OrchestrationDeployAction.'
                 '_extract_container_object_from_swift_url')
@@ -124,9 +124,9 @@ class OrchestrationDeployActionTest(base.TestCase):
                                                            'object')
         get_obj_client_mock.delete_container.called_once_with('container')
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('heatclient.common.deployment_utils.create_temp_url')
     @mock.patch('tripleo_common.actions.deployment.OrchestrationDeployAction.'
                 '_extract_container_object_from_swift_url')
@@ -157,9 +157,9 @@ class OrchestrationDeployActionTest(base.TestCase):
                                                            'object')
         get_obj_client_mock.delete_container.called_once_with('container')
 
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('heatclient.common.deployment_utils.create_temp_url')
     @mock.patch('tripleo_common.actions.deployment.OrchestrationDeployAction.'
                 '_extract_container_object_from_swift_url')
@@ -201,10 +201,10 @@ class DeployStackActionTest(base.TestCase):
                 'process_multiple_environments_and_files')
     @mock.patch('heatclient.common.template_utils.get_template_contents')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_orchestration_client')
+        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
     @mock.patch('mistral.context.ctx')
     def test_run(self, mock_ctx, get_orchestration_client_mock,
                  mock_get_object_client, mock_get_workflow_client,
@@ -260,85 +260,14 @@ class DeployStackActionTest(base.TestCase):
             template={'heat_template_version': '2016-04-30'},
             timeout_mins=1,
         )
-        swift.delete_object.assert_called_once_with(
-            "overcloud-swift-rings", "swift-rings.tar.gz")
-        swift.copy_object.assert_called_once_with(
-            "overcloud-swift-rings", "swift-rings.tar.gz",
-            "overcloud-swift-rings/swift-rings.tar.gz-%d" % 1473366264)
-
-    @mock.patch('tripleo_common.actions.deployment.time')
-    @mock.patch('heatclient.common.template_utils.'
-                'process_multiple_environments_and_files')
-    @mock.patch('heatclient.common.template_utils.get_template_contents')
-    @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
-    @mock.patch(
-        'tripleo_common.actions.base.TripleOAction._get_orchestration_client')
-    @mock.patch('mistral.context.ctx')
-    def test_run_skip_deploy_identifier(
-            self, mock_ctx, get_orchestration_client_mock,
-            mock_get_object_client, mock_get_workflow_client,
-            mock_get_template_contents,
-            mock_process_multiple_environments_and_files,
-            mock_time):
-
-        mock_ctx.return_value = mock.MagicMock()
-        # setup swift
-        swift = mock.MagicMock(url="http://test.com")
-        swift.get_object.side_effect = swiftexceptions.ClientException(
-            'atest2')
-        mock_get_object_client.return_value = swift
-
-        heat = mock.MagicMock()
-        heat.stacks.get.return_value = None
-        get_orchestration_client_mock.return_value = heat
-
-        mock_mistral = mock.MagicMock()
-        mock_env = mock.MagicMock()
-        mock_env.variables = {
-            'temp_environment': 'temp_environment',
-            'template': 'template',
-            'environments': [{u'path': u'environments/test.yaml'}],
-            'parameter_defaults': {'random_existing_data': 'a_value'},
-        }
-        mock_mistral.environments.get.return_value = mock_env
-        mock_get_workflow_client.return_value = mock_mistral
-
-        mock_get_template_contents.return_value = ({}, {
-            'heat_template_version': '2016-04-30'
-        })
-        mock_process_multiple_environments_and_files.return_value = ({}, {})
-
-        # freeze time at datetime.datetime(2016, 9, 8, 16, 24, 24)
-        mock_time.time.return_value = 1473366264
-
-        action = deployment.DeployStackAction(1, 'overcloud',
-                                              skip_deploy_identifier=True)
-        action.run()
-
-        # verify parameters are as expected
-        expected_defaults = {'StackAction': 'CREATE',
-                             'UpdateIdentifier': '',
-                             'random_existing_data': 'a_value'}
-        self.assertEqual(expected_defaults,
-                         mock_env.variables['parameter_defaults'])
-
-        heat.stacks.create.assert_called_once_with(
-            environment={},
-            files={},
-            stack_name='overcloud',
-            template={'heat_template_version': '2016-04-30'},
-            timeout_mins=1,
-        )
 
 
 class OvercloudRcActionTestCase(base.TestCase):
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('mistral.context.ctx')
     def test_no_stack(self, mock_context, mock_get_orchestration,
                       mock_get_workflow):
@@ -355,9 +284,9 @@ class OvercloudRcActionTestCase(base.TestCase):
         ))
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('mistral.context.ctx')
     def test_no_env(self, mock_context, mock_get_orchestration,
                     mock_get_workflow):
@@ -373,9 +302,9 @@ class OvercloudRcActionTestCase(base.TestCase):
             "The Mistral environment overcast cound not be found.")
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('mistral.context.ctx')
     def test_no_password(self, mock_context, mock_get_orchestration,
                          mock_get_workflow):
@@ -392,9 +321,9 @@ class OvercloudRcActionTestCase(base.TestCase):
 
     @mock.patch('tripleo_common.utils.overcloudrc.create_overcloudrc')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('mistral.context.ctx')
     def test_no_success(self, mock_context, mock_get_orchestration,
                         mock_get_workflow, mock_create_overcloudrc):
