@@ -42,6 +42,7 @@ _EXISTING_PASSWORDS = {
     'HeatStackDomainAdminPassword': 'GgTRyWzKYsxK4mReTJ4CM6sMc',
     'CephRgwKey': b'AQCQXtlXAAAAABAAUKcqUMu6oMjAXMjoUV4/3A==',
     'AodhPassword': '8VZXehsKc2HbmFFMKYuqxTJHn',
+    'PankoPassword': 'cVZXehsSc2KdmFFMKDudxTLKn',
     'ManilaPassword': 'NYJN86Fua3X8AVFWmMhQa2zTH',
     'NeutronMetadataProxySharedSecret': 'Q2YgUCwmBkYdqsdhhCF4hbghu',
     'CephMonKey': b'AQCQXtlXAAAAABAA9l+59N3yH+C49Y0JiKeGFg==',
@@ -52,10 +53,11 @@ _EXISTING_PASSWORDS = {
     'MysqlClustercheckPassword': 'jN4RMMWWJ4sycaRwh7UvrAtfX',
     'CephClientKey': b'AQCQXtlXAAAAABAAKyc+8St8i9onHyu2mPk+vg==',
     'NeutronPassword': 'ZxAjdU2UXCV4GM3WyPKrzAZXD',
-    'MigrationSshKey': {
-        'private_key': 'private_key',
-        'public_key': 'public_key'
-        },
+    'KeystoneCredential0': 'ftJNQ_XlDUK7Lgvv1kdWf3SyqVsrvNDgoNV4kJg3yzw=',
+    'KeystoneCredential1': 'c4MFq82TQLFLKpiiUjrKkp15dafE2ALcD3jbaIu3rfE=',
+    'KeystoneFernetKey0': 'O8NSPxr4zXBBAoGIj-5aUmtE7-Jk5a4ptVsEhzJ8Vd8=',
+    'KeystoneFernetKey1': 'AueoL37kd6eLjV29AG-Ruxu5szW47osgXx6aPOqtI6I=',
+    'CephClusterFSID': u'97c16f44-b62c-11e6-aed3-185e0f73fdc5',
 }
 
 
@@ -65,10 +67,10 @@ class GetParametersActionTest(base.TestCase):
                 'process_multiple_environments_and_files')
     @mock.patch('heatclient.common.template_utils.get_template_contents')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
-    @mock.patch('tripleo_common.actions.base.TripleOAction._get_object_client')
+                'get_workflow_client')
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
     @mock.patch('mistral.context.ctx')
     def test_run(self, mock_ctx, mock_get_object_client,
                  mock_get_workflow_client, mock_get_orchestration_client,
@@ -113,7 +115,7 @@ class GetParametersActionTest(base.TestCase):
 class ResetParametersActionTest(base.TestCase):
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('mistral.context.ctx')
     def test_run(self, mock_ctx, mock_get_workflow_client):
 
@@ -144,7 +146,7 @@ class ResetParametersActionTest(base.TestCase):
 class UpdateParametersActionTest(base.TestCase):
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('mistral.context.ctx')
     def test_run(self, mock_ctx, mock_get_workflow_client):
 
@@ -179,11 +181,11 @@ class UpdateRoleParametersActionTest(base.TestCase):
 
     @mock.patch('tripleo_common.utils.parameters.set_count_and_flavor_params')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_baremetal_client')
+                'get_baremetal_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_compute_client')
+                'get_compute_client')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('mistral.context.ctx')
     def test_run(self, mock_ctx, mock_get_workflow_client,
                  mock_get_compute_client, mock_get_baremetal_client,
@@ -212,11 +214,11 @@ class UpdateRoleParametersActionTest(base.TestCase):
 class GeneratePasswordsActionTest(base.TestCase):
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
+                'get_orchestration_client')
     @mock.patch('tripleo_common.utils.passwords.'
                 'get_snmpd_readonly_user_password')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client', return_value="TestPassword")
+                'get_workflow_client', return_value="TestPassword")
     @mock.patch('mistral.context.ctx')
     def test_run(self, mock_ctx, mock_get_workflow_client,
                  mock_get_snmpd_readonly_user_password,
@@ -250,22 +252,17 @@ class GeneratePasswordsActionTest(base.TestCase):
                             "%s is not in %s" % (password_param_name, result))
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
-    @mock.patch('tripleo_common.utils.passwords.'
-                'create_ssh_keypair')
+                'get_orchestration_client')
     @mock.patch('tripleo_common.utils.passwords.'
                 'get_snmpd_readonly_user_password')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('mistral.context.ctx')
     def test_run_passwords_exist(self, mock_ctx, mock_get_workflow_client,
                                  mock_get_snmpd_readonly_user_password,
-                                 mock_create_ssh_keypair,
                                  mock_get_orchestration_client):
 
         mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
-        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
-                                                'private_key': 'Bar'}
 
         mock_ctx.return_value = mock.MagicMock()
         mock_mistral = mock.MagicMock()
@@ -275,7 +272,7 @@ class GeneratePasswordsActionTest(base.TestCase):
             'temp_environment': 'temp_environment',
             'template': 'template',
             'environments': [{u'path': u'environments/test.yaml'}],
-            'passwords': _EXISTING_PASSWORDS
+            'passwords': _EXISTING_PASSWORDS.copy()
         }
         mock_mistral.environments.get.return_value = mock_env
         mock_get_workflow_client.return_value = mock_mistral
@@ -293,22 +290,17 @@ class GeneratePasswordsActionTest(base.TestCase):
         self.assertEqual(_EXISTING_PASSWORDS, result)
 
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_orchestration_client')
-    @mock.patch('tripleo_common.utils.passwords.'
-                'create_ssh_keypair')
+                'get_orchestration_client')
     @mock.patch('tripleo_common.utils.passwords.'
                 'get_snmpd_readonly_user_password')
     @mock.patch('tripleo_common.actions.base.TripleOAction.'
-                '_get_workflow_client')
+                'get_workflow_client')
     @mock.patch('mistral.context.ctx')
     def test_passwords_exist_in_heat(self, mock_ctx, mock_get_workflow_client,
                                      mock_get_snmpd_readonly_user_password,
-                                     mock_create_ssh_keypair,
                                      mock_get_orchestration_client):
 
         mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
-        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
-                                                'private_key': 'Bar'}
 
         existing_passwords = _EXISTING_PASSWORDS.copy()
         existing_passwords.pop("AdminPassword")
@@ -321,7 +313,7 @@ class GeneratePasswordsActionTest(base.TestCase):
             'temp_environment': 'temp_environment',
             'template': 'template',
             'environments': [{u'path': u'environments/test.yaml'}],
-            'passwords': existing_passwords
+            'passwords': existing_passwords.copy()
         }
         mock_mistral.environments.get.return_value = mock_env
         mock_get_workflow_client.return_value = mock_mistral
